==> components-2.0.0.tgz: package/esm/Molecules/SearchBars/SearchBarUnderlined.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _templateObject3() {
  var data = _taggedTemplateLiteral(["\n  display: flex;\n  flex-direction: row;\n  justify-content: center;\n  align-items: center;\n  width: 60px;\n  height: 40px;\n"]);

  _templateObject3 = function _templateObject3() {
    return data;
  };

  return data;
}

function _templateObject2() {
  var data = _taggedTemplateLiteral(["\n  background-color: inherit;\n  border-color: transparent;\n"]);

  _templateObject2 = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject() {
  var data = _taggedTemplateLiteral(["\n  display: flex;\n  flex-direction: row;\n  justify-content: flex-start;\n  align-items: center;\n  width: ", ";\n  border-bottom: 1px solid\n    ", ";\n  background-color: ", ";\n"]);

  _templateObject = function _templateObject() {
    return data;
  };

  return data;
}

function _taggedTemplateLiteral(strings, raw) { if (!raw) { raw = strings.slice(0); } return Object.freeze(Object.defineProperties(strings, { raw: { value: Object.freeze(raw) } })); }

import React from 'react';
import PropTypes from 'prop-types';
import styled from 'styled-components';
import { Input } from '../../Atoms/Inputs';
import { FaIcon } from '../../Atoms/Icons';
var Wrapper = styled.div(_templateObject(), function (props) {
  return props.width;
}, function (props) {
  return props.theme['searchBarUnderlinedBorderColor'];
}, function (props) {
  return props.theme['searchBarUnderlinedBackgroundColor'];
});
var SearchInput = styled(Input)(_templateObject2());
var IconContainer = styled.div(_templateObject3());

var SearchBarUnderlined = function SearchBarUnderlined(_ref) {
  var children = _ref.children,
      width = _ref.width,
      onChange = _ref.onChange,
      onClick = _ref.onClick,
      value = _ref.value,
      rest = _objectWithoutProperties(_ref, ["children", "width", "onChange", "onClick", "value"]);

  return React.createElement(Wrapper, {
    width: width
  }, React.createElement(SearchInput, _extends({
    onChange: onChange,
    value: value
  }, rest)), React.createElement(IconContainer, null, React.createElement(FaIcon.Search, {
    onClick: onClick,
    selectable: true,
    size: "1.3rem"
  })));
};

SearchBarUnderlined.propTypes = {
  children: PropTypes.node,
  onChange: PropTypes.func,
  onClick: PropTypes.func,
  value: PropTypes.any,
  width: PropTypes.string
};
SearchBarUnderlined.defaultProps = {
  width: '100%'
};
export default SearchBarUnderlined;

==> components-2.0.2.tgz: package/esm/Molecules/SearchBars/SearchBarUnderlined.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _templateObject3() {
  var data = _taggedTemplateLiteral(["\n  display: flex;\n  flex-direction: row;\n  justify-content: center;\n  align-items: center;\n  width: 60px;\n  height: 40px;\n"]);

  _templateObject3 = function _templateObject3() {
    return data;
  };

  return data;
}

function _templateObject2() {
  var data = _taggedTemplateLiteral(["\n  background-color: inherit;\n  border-color: transparent;\n"]);

  _templateObject2 = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject() {
  var data = _taggedTemplateLiteral(["\n  display: flex;\n  flex-direction: row;\n  justify-content: flex-start;\n  align-items: center;\n  width: ", ";\n  border-bottom: 1px solid\n    ", ";\n  background-color: ", ";\n"]);

  _templateObject = function _templateObject() {
    return data;
  };

  return data;
}

function _taggedTemplateLiteral(strings, raw) { if (!raw) { raw = strings.slice(0); } return Object.freeze(Object.defineProperties(strings, { raw: { value: Object.freeze(raw) } })); }

import React from 'react';
import PropTypes from 'prop-types';
import styled from 'styled-components';
import { FasSearch } from '../../Atoms/Icons';
import { Input } from '../../Atoms/Inputs';
var Wrapper = styled.div(_templateObject(), function (props) {
  return props.width;
}, function (props) {
  return props.theme['searchBarUnderlinedBorderColor'];
}, function (props) {
  return props.theme['searchBarUnderlinedBackgroundColor'];
});
var SearchInput = styled(Input)(_templateObject2());
var IconContainer = styled.div(_templateObject3());

var SearchBarUnderlined = function SearchBarUnderlined(_ref) {
  var children = _ref.children,
      width = _ref.width,
      onChange = _ref.onChange,
      onClick = _ref.onClick,
      value = _ref.value,
      rest = _objectWithoutProperties(_ref, ["children", "width", "onChange", "onClick", "value"]);

  return React.createElement(Wrapper, {
    width: width
  }, React.createElement(SearchInput, _extends({
    onChange: onChange,
    value: value
  }, rest)), React.createElement(IconContainer, null, React.createElement(FasSearch, {
    onClick: onClick,
    selectable: true,
    size: "1.3rem"
  })));
};

SearchBarUnderlined.propTypes = {
  children: PropTypes.node,
  onChange: PropTypes.func,
  onClick: PropTypes.func,
  value: PropTypes.any,
  width: PropTypes.string
};
SearchBarUnderlined.defaultProps = {
  width: '100%'
};
export default SearchBarUnderlined;
